@@ -1,4 +1,4 @@
-//#undef __LCRT_DEBUG__
+#undef __LCRT_DEBUG__
 #include "debug.h"
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -22,7 +22,11 @@ int lcrt_qconnect_init_config(struct lcrt_qconnect *lqconnect);
 int lcrt_qconnect_load_config(struct lcrt_qconnect *lqconnect);
 int lcrt_qconnect_create_config(struct lcrt_qconnect *lqconnect);
 
-int lcrt_create_qconnect(struct lcrt_window *parent, GtkWindow *window, gboolean tab)
+int lcrt_create_qconnect(
+    struct lcrt_window *parent, 
+    GtkWindow *window, 
+    lcrt_qconnect_flag_t flag, 
+    const char *uname)
 {
     struct lcrt_qconnect *lqconnect;
 
@@ -76,7 +80,8 @@ int lcrt_create_qconnect(struct lcrt_window *parent, GtkWindow *window, gboolean
         goto err;
 
     lqconnect->parent = parent;
-    lqconnect->tab = tab;
+    lqconnect->flag = flag;
+    lqconnect->uname = uname;
     debug_where();
 
     lcrt_qconnect_init_config(lqconnect);
@@ -90,8 +95,10 @@ int lcrt_create_qconnect(struct lcrt_window *parent, GtkWindow *window, gboolean
             window != NULL ? window : GTK_WINDOW(lqconnect->parent->window));
     gtk_widget_show(quick_connect);
     lqconnect->q_connect = quick_connect;
-
-    gtk_window_set_title (GTK_WINDOW (quick_connect), lqconnect->config.value[LCRT_Q_CONNECT]);
+    if (flag == LCRT_QCONNECT_SESSION_OPTION)
+        gtk_window_set_title (GTK_WINDOW (quick_connect), lqconnect->config.value[LCRT_Q_SESSION_OPTION]);
+    else
+        gtk_window_set_title (GTK_WINDOW (quick_connect), lqconnect->config.value[LCRT_Q_CONNECT]);
     gtk_window_set_modal(GTK_WINDOW(quick_connect), TRUE);
     gtk_window_set_position (GTK_WINDOW (quick_connect), GTK_WIN_POS_CENTER_ON_PARENT);
     gtk_window_set_resizable (GTK_WINDOW (quick_connect), FALSE);
@@ -318,8 +325,10 @@ int lcrt_create_qconnect(struct lcrt_window *parent, GtkWindow *window, gboolean
     g_signal_connect ((gpointer) button_cancel, "clicked",
                     G_CALLBACK (lcrt_qconnect_on_button_cancel_clicked),
                     lqconnect);
-
-    button_connect = gtk_button_new_with_mnemonic (lqconnect->config.value[LCRT_Q_BT_CONNECT]);
+    if (flag == LCRT_QCONNECT_SESSION_OPTION)
+        button_connect = gtk_button_new_with_mnemonic (lqconnect->config.value[LCRT_Q_BT_OK]);
+    else
+        button_connect = gtk_button_new_with_mnemonic (lqconnect->config.value[LCRT_Q_BT_CONNECT]);
     lqconnect->q_bt_connect = button_connect;
     gtk_widget_show (button_connect);
     gtk_dialog_add_action_widget (GTK_DIALOG (quick_connect), button_connect, GTK_RESPONSE_OK);
@@ -338,7 +347,17 @@ int lcrt_create_qconnect(struct lcrt_window *parent, GtkWindow *window, gboolean
     gtk_window_set_focus(GTK_WINDOW(quick_connect), entry_hostname);
     debug_where();
     gtk_window_add_accel_group (GTK_WINDOW (quick_connect), accel_group);
-
+    if (flag == LCRT_QCONNECT_SESSION_OPTION) {
+        struct lcrtc_user *user;
+        char tmp[32];
+        if ((user = lcrt_user_find_by_name(&parent->u_config, uname)) != NULL) {
+            gtk_combo_box_set_active(GTK_COMBO_BOX(lqconnect->q_cb_protocol), user->protocol);
+            gtk_entry_set_text(GTK_ENTRY(lqconnect->q_et_hostname), user->hostname);
+            gtk_entry_set_text(GTK_ENTRY(lqconnect->q_et_username), user->username);
+            sprintf(tmp, "%d", user->port);
+            gtk_entry_set_text(GTK_ENTRY(lqconnect->q_et_port), tmp);
+        }
+    }
     return gtk_dialog_run(GTK_DIALOG(quick_connect));
 err:
     lcrt_message_error(parent->window, lqconnect->config.value[LCRT_Q_ERR_MSG]);
